{% load theme_tags %} {% load news_tags %} {% list_news as featured_news limit=TEMPLATE_NEWS_LIST_LIMIT %}

### {% firstof TEMPLATE_NEWS_LIST_TITLE 'News' %}

{% if featured_news %} {% for news_item in featured_news|slice:":1" %}

#### {{ news_item.headline }}

{{ news_item.body|striptags|truncatewords:30|safe }}

Read more {% endfor %} {% else %}

Tendenci supports great news updates for your members and website visitors. You can pull extra details from the latest news, while showing other news items to the side. {% if request.user.is_authenticated %}Add your first news item to take the place of these examples.{% endif %}

Read more {% endif %}

{% if featured_news|length > 1 %} {% for news_item in featured_news %} {% if forloop.first %} {% else %}
- {{ news_item.headline|truncatewords:4|safe }}
{% endif %} {% endfor %} {% else %}
- Another top story in the news
- Even more great news updates
{% endif %}

{% theme_setting setting_name %}